@@ -1,10 +1,11 @@
-from transform.mql import MQLClient
+from .mql import MQLClient
 
-__version__ = "0.0.49"
+__version__ = "0.0.51"
 PACKAGE_NAME = "transform"
 
 # mql gets imported if user is already authenticated
+mql = None
 try:
     mql = MQLClient()
 except Exception as e:  # noqa: D
-    mql = None
+    pass
