@@ -78,13 +78,15 @@ class TransformAuth:  # noqa: D
         self.config._set_config_value(BEARER_TOKEN_EXPIRES_AT_CONFIG_KEY, bearer_token_expires_at)
 
     @property
-    def auth_header(self) -> Optional[Dict[str, str]]:
+    def auth_header(self) -> Dict[str, str]:
         """Get auth header based on creds in config file. If none, return None."""
         if not self.__auth_header:
             if self.api_key is not None:
                 self.__auth_header = {"Authorization": f"X-Api-Key {self.api_key}"}
             elif self.bearer_token is not None:
                 self.__auth_header = {"Authorization": f"Bearer {self.bearer_token}"}
+        if self.__auth_header is None:
+            raise AuthException
         return self.__auth_header
 
     @property
