@@ -19,7 +19,9 @@ from ..models import ModelKey, UserState
 from ..mql import MQLClient
 
 
-class CLIContext(TransformAuth):  # noqa: D
+class CLIContext(TransformAuth):
+    """Context configs for CLI. Inherits base TransformAuth."""
+
     def __init__(self) -> None:  # noqa: D
         self.verbose = False
         self.__user_state: Optional[UserState] = None
@@ -27,10 +29,14 @@ class CLIContext(TransformAuth):  # noqa: D
         super().__init__()
         self.mql = MQLClient()
 
+    @property
+    def api_key(self) -> Optional[str]:  # noqa: D
+        return super().api_key
+
     @TransformAuth.api_key.setter
-    def api_key(self, api_key: str) -> None:
+    def api_key(self, api_key: str) -> None:  # noqa: D
         """Set the users' API key and record to the config file."""
-        TransformAuth.api_key.fset(self, api_key)
+        TransformAuth.api_key.fset(self, api_key)  # type: ignore
         self.identify()
         self.__just_authenticated = True
         click.echo("✨ Success! We've set your Transform API key. We're ready to query.\n")
@@ -58,7 +64,7 @@ class CLIContext(TransformAuth):  # noqa: D
 
     @TransformAuth.bearer_token.setter
     def bearer_token(self, bearer_token: str) -> None:  # noqa: D
-        TransformAuth.bearer_token.fset(self, bearer_token)
+        TransformAuth.bearer_token.fset(self, bearer_token)  # type: ignore
         self.identify()
         self.__just_authenticated = True
         if self.bearer_token_expires_at is not None:
@@ -282,8 +288,12 @@ class CLIContext(TransformAuth):  # noqa: D
 
         click.echo(msg)
 
+    @property
+    def mql_server_url_config_override(self) -> Optional[str]:  # noqa: D
+        return super().mql_server_url_config_override
+
     @TransformAuth.mql_server_url_config_override.setter
     def mql_server_url_config_override(self, mql_server_url: str) -> None:  # noqa: D
-        TransformAuth.mql_server_url_config_override.fset(self, mql_server_url)
+        TransformAuth.mql_server_url_config_override.fset(self, mql_server_url)  # type: ignore
         if mql_server_url:
             click.echo(f"Success! We've overriden your MQL server to {mql_server_url}")
