@@ -6,7 +6,7 @@ import textwrap
 
 import pandas as pd
 from halo import Halo
-from typing import List, Optional
+from typing import Dict, List, Optional
 
 from log_symbols import LogSymbols
 from packaging.version import parse
@@ -26,7 +26,16 @@ from .cli_utils import (
     query_observability_options,
     exception_handler,
 )
-from ..models import CacheMode, PercentChange, HealthReportStatus, DEFAULT_LIMIT, INF, NEGATIVE_ONE, TimeGranularity
+from ..models import (
+    CacheMode,
+    PercentChange,
+    Query,
+    HealthReportStatus,
+    DEFAULT_LIMIT,
+    INF,
+    NEGATIVE_ONE,
+    TimeGranularity,
+)
 from .. import PACKAGE_NAME, __version__
 
 pass_config = click.make_pass_decorator(CLIContext, ensure=True)
@@ -228,10 +237,14 @@ def list_servers(config: CLIContext) -> None:
 @exception_handler
 def health_report(config: CLIContext) -> None:
     """Completes a health check on MQL servers."""
+    spinner = Halo(text="Checking health of MQL servers...", spinner="dots")
+    spinner.start()
     servers = config.mql.health_report()
     if len(servers) == 0:
+        spinner.fail()
         no_active_mql_servers(config.org.name)
         exit()
+    spinner.succeed("Successfully built health report!")
 
     click.echo(
         f"🏥 Health Report for {len(servers)} MQL Servers at {config.org.name}",
@@ -484,6 +497,7 @@ def drop_materialization(
     type=str,
     help="Write materialized result to specified table of format '<schema>.<table_name>'",
 )
+@click.option("--force", "-f", is_flag=True, default=False)
 @async_options
 @query_observability_options
 @pass_config
@@ -499,10 +513,11 @@ def materialize(
     end_time: Optional[str] = None,
     config_dir: Optional[str] = None,
     output_table: Optional[str] = None,
+    force: bool = False,
     web: bool = False,
     debug: bool = False,
 ) -> None:
-    """***NEW*** Create a new MQL materialization query, polls for completion and returns materialized table id"""
+    """Create a new MQL materialization query, polls for completion and returns materialized table id"""
     # Note: calling config.resolve_query_model_key may initiate a dialog if the user has a pinned model
     # Purposefully pulling this out before the spinner
     model_key = config.resolve_query_model_key(config_dir)
@@ -529,6 +544,7 @@ def materialize(
         start_time=start_time,
         end_time=end_time,
         output_table=output_table,
+        force=force,
     ).query_id
 
     spinner.succeed(f"Query initialized: {query_id}")
@@ -563,10 +579,14 @@ def materialize(
 def list_materializations(config: CLIContext, search: Optional[str] = None) -> None:
     """List the materializations for the Organization with their available metrics and dimensions."""
 
+    spinner = Halo(text="Looking for all available materializations...", spinner="dots")
+    spinner.start()
+
     model_key = config.resolve_query_model_key()
     materializations = config.mql.list_materializations(model_key.id if model_key else None)
     if not materializations:
-        click.echo("List of materializations unavailable.")
+        spinner.fail("List of materializations unavailable.")
+        exit()
 
     filter_msg = ""
     if search is not None:
@@ -574,7 +594,7 @@ def list_materializations(config: CLIContext, search: Optional[str] = None) -> N
         materializations = [m for m in materializations if search.lower() in m.name.lower()]
         filter_msg = f" matching `{search}`, of a total of {count} available"
 
-    click.echo(
+    spinner.succeed(
         f"🌱 We've found {len(materializations)} materializations for the {config.org.name} organization{filter_msg}."
     )
     click.echo(
@@ -608,12 +628,19 @@ def list_materializations(config: CLIContext, search: Optional[str] = None) -> N
 @exception_handler
 def get_dimension_values(config: CLIContext, dimension_name: str, metric_name: str) -> None:
     """List all dimension values that are queryable through materialized tables."""
+
+    spinner = Halo(
+        text=f"Retrieving dimension values for dimension {dimension_name} of metric {metric_name}...", spinner="dots"
+    )
+    spinner.start()
+
     model_key = config.resolve_query_model_key()
     try:
         dim_vals = sorted(
             config.mql.get_dimension_values(metric_name, dimension_name, model_key.id if model_key else None)
         )
     except Exception as e:
+        spinner.fail()
         click.echo(
             textwrap.dedent(
                 f"""\
@@ -627,7 +654,7 @@ def get_dimension_values(config: CLIContext, dimension_name: str, metric_name: s
         )
         exit(1)
 
-    click.echo(
+    spinner.succeed(
         f"🌱 We've found {len(dim_vals)} dimension values for dimension {dimension_name} of metric {metric_name}."
     )
     for dim_val in dim_vals:
@@ -647,10 +674,14 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
 
     # Note: calling config.resolve_query_model_key may initiate a dialog if the user has a pinned model
     # Purposefully pulling this out before the spinner
+
+    spinner = Halo(text="Looking for all available metrics...", spinner="dots")
+    spinner.start()
+
     model_key = config.resolve_query_model_key()
     metrics = sorted(config.mql.list_metrics(model_key.id if model_key else None).values(), key=lambda m: m.name)
     if not metrics:
-        click.echo("List of metrics unavailable.")
+        spinner.fail("List of metrics unavailable.")
 
     filter_msg = ""
     if search is not None:
@@ -658,7 +689,7 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
         metrics = [m for m in metrics if search.lower() in m.name.lower()]
         filter_msg = f" matching `{search}`, of a total of {num_org_metrics} available"
 
-    click.echo(f"🌱 We've found {len(metrics)} metrics for the {config.org.name} organization{filter_msg}.")
+    spinner.succeed(f"🌱 We've found {len(metrics)} metrics for the {config.org.name} organization{filter_msg}.")
     click.echo('The list below shows metrics in the format of "metric_name: list of available dimensions"')
     num_dims_to_show = MAX_LIST_OBJECT_ELEMENTS
     for m in metrics:
@@ -679,12 +710,16 @@ def list_metrics(config: CLIContext, show_all_dims: bool = False, search: Option
 @exception_handler
 def list_dimensions(config: CLIContext) -> None:
     """List all unique dimensions for the Organization."""
+
+    spinner = Halo(text="Looking for all available dimensions...", spinner="dots")
+    spinner.start()
+
     model_key = config.resolve_query_model_key()
     dimensions = sorted(config.mql.list_dimensions(model_key.id if model_key else None).values(), key=lambda d: d.name)
     if not dimensions:
-        click.echo("List of dimensions unavailable.")
+        spinner.fail("List of dimensions unavailable.")
 
-    click.echo(f"🌱 We've found {len(dimensions)} unique dimensions for the {config.org.name} organization.")
+    spinner.succeed(f"🌱 We've found {len(dimensions)} unique dimensions for the {config.org.name} organization.")
     for d in dimensions:
         click.echo(f"• {click.style(d.name, bold=True, fg='green')}")
 
@@ -730,16 +765,40 @@ def list_queries(
     limit: Optional[int] = None,
 ) -> None:
     """Retrieve queries from mql server"""
-    click.echo(config.mql.list_queries(active_only=active_only, limit=limit))
+
+    active_query_str = "active" if active_only else "non-active"
+    spinner = Halo(text=f"Looking for all {active_query_str} queries...", spinner="dots")
+    spinner.start()
+
+    queries = config.mql.list_queries(active_only=active_only, limit=limit)
+
+    spinner.succeed(f"🌱 We've found {len(queries)} {active_query_str} queries. Grouped by branch-commit,")
+
+    # group queries by branch-commit
+    grouped_queries: Dict[str, List[Query]] = {}
+    for q in queries:
+        branch_commit = f"{q.branch}-{q.commit}"
+        if branch_commit not in grouped_queries:
+            grouped_queries[branch_commit] = []
+        grouped_queries[branch_commit].append(q)
+
+    for group in grouped_queries:
+        click.echo(click.style(group, bold=True, fg=("green")))
+        for q in grouped_queries[group]:
+            click.echo(f"• query_id={q.id}, status={q.status.value}")
 
 
 @cli.command()
 @config_validation_options
 @pass_config
+@exception_handler
 def validate_configs(config: CLIContext, config_dir: str) -> None:
     """Validate yaml configs found in specified config directory"""
+
+    spinner = Halo(text=f"Validating configs in '{config_dir}'...", spinner="dots")
+    spinner.start()
     repo, branch, commit = config.mql.validate_configs(config_dir)
-    click.echo(f"🎉 Successfully validated configs for commit ({commit}) in repo ({repo}), on branch ({branch})")
+    spinner.succeed(f"🎉 Successfully validated configs for commit ({commit}) in repo ({repo}), on branch ({branch})")
 
 
 @cli.command()
