@@ -29,6 +29,7 @@ from .models import (
     MQLServer,
     MQLServerImage,
     PercentChange,
+    Query,
     HealthReport,
     UserState,
     TimeGranularity,
@@ -122,7 +123,7 @@ class BackendInterface(BaseInterface):  # noqa: D
             if len(error_content) == 2:
                 error_response = json.loads(error_content[1])["error"]
                 error_msg = f"🙈 {error_response['error_type']}: {error_response['message']}"
-            raise Exception(error_msg)
+            raise Exception(error_msg) from None
 
     def validate_configs(self, config_dir: str) -> Tuple[str, str, str]:  # noqa: D
         """Finds and validates yaml configs in the provided directory"""
@@ -293,7 +294,7 @@ class BackendInterface(BaseInterface):  # noqa: D
         )
         return MQLServerImage.from_gql_dict(self.execute(query)["latestMqlServer"])
 
-    def get_metrics_metadata(self) -> List[Dict[str, Any]]:
+    def get_metrics_metadata(self) -> List[Dict[str, Any]]:  # type: ignore[misc]
         """Fetch all org metrics' metadata."""
         query = gql(
             """
@@ -328,7 +329,7 @@ class BackendInterface(BaseInterface):  # noqa: D
         )
         return self.execute(query, variable_values={"pageSize": MAX_PAGE_SIZE})["myOrganization"]["metrics"]
 
-    def get_metric_metadata_by_name(self, metric_name: str) -> Dict[str, Any]:
+    def get_metric_metadata_by_name(self, metric_name: str) -> Dict[str, Any]:  # type: ignore[misc]
         """Fetch a single org metric metadata."""
         query = gql(
             """
@@ -463,91 +464,55 @@ class MQLInterface(BaseInterface):  # noqa: D
         end_time: Optional[str],
         model_key: Optional[ModelKey] = None,
         output_table: Optional[str] = None,
+        force: bool = False,
     ) -> str:
         """Implements Materialize (new) mutation in MQL/GQL"""
         # Note: we omit the outputTable var if arg is not passed to maintain backwards compatibility with servers
         # that don't recognize it (ie if they're not on 0e7448e8b6a75484f806c32c7f74e3aafbf11b7d or later)
-        if output_table is not None:
-            query = gql(
-                """
-                mutation CreateMqlMaterializationNewMutation(
-                    $materializationName: String!
-                    $startTime: String
-                    $endTime: String
-                    $modelKey: ModelKeyInput
-                    $outputTable: String
+        query = gql(
+            """
+            mutation CreateMqlMaterializationNewMutation(
+                $materializationName: String!
+                $startTime: String
+                $endTime: String
+                $modelKey: ModelKeyInput
+                $outputTable: String
+                $force: Boolean
+            ) {
+                createMqlMaterializationNew(
+                    input: {
+                        modelKey: $modelKey,
+                        materializationName: $materializationName,
+                        startTime: $startTime,
+                        endTime: $endTime,
+                        outputTable: $outputTable
+                        force: $force
+                    }
                 ) {
-                    createMqlMaterializationNew(
-                        input: {
-                            modelKey: $modelKey,
-                            materializationName: $materializationName,
-                            startTime: $startTime,
-                            endTime: $endTime,
-                            outputTable: $outputTable
-                        }
-                    ) {
-                        id
-                    }
+                    id
                 }
-                """
-            )
+            }
+            """
+        )
 
-            return self.execute(
-                query,
-                variable_values={
-                    "modelKey": {
-                        "organization": model_key.organization_id,
-                        "repo": model_key.repository,
-                        "branch": model_key.branch,
-                        "commit": model_key.commit,
-                    }
-                    if model_key
-                    else None,
-                    "materializationName": materialization_name,
-                    "startTime": start_time,
-                    "endTime": end_time,
-                    "outputTable": output_table,
-                },
-            )["createMqlMaterializationNew"]["id"]
-        else:
-            query = gql(
-                """
-                mutation CreateMqlMaterializationNewMutation(
-                    $materializationName: String!
-                    $startTime: String
-                    $endTime: String
-                    $modelKey: ModelKeyInput
-                ) {
-                    createMqlMaterializationNew(
-                        input: {
-                            modelKey: $modelKey,
-                            materializationName: $materializationName,
-                            startTime: $startTime,
-                            endTime: $endTime,
-                        }
-                    ) {
-                        id
-                    }
+        return self.execute(
+            query,
+            variable_values={
+                "modelKey": {
+                    "organization": model_key.organization_id,
+                    "repo": model_key.repository,
+                    "branch": model_key.branch,
+                    "commit": model_key.commit,
                 }
-                """
-            )
-
-            return self.execute(
-                query,
-                variable_values={
-                    "modelKey": {
-                        "organization": model_key.organization_id,
-                        "repo": model_key.repository,
-                        "branch": model_key.branch,
-                        "commit": model_key.commit,
-                    }
-                    if model_key
-                    else None,
-                    "materializationName": materialization_name,
-                    "startTime": start_time,
-                    "endTime": end_time,
-                },
-            )["createMqlMaterializationNew"]["id"]
+                if model_key
+                else None,
+                "materializationName": materialization_name,
+                "startTime": start_time,
+                "endTime": end_time,
+                "outputTable": output_table,
+                "force": force,
+            },
+        )["createMqlMaterializationNew"]["id"]
 
     def get_materializations(self, model_key: Optional[ModelKey] = None) -> List[Materialization]:  # noqa: D
         query = gql(
@@ -663,7 +628,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             )["metrics"]
         ]
 
-    def get_metric_by_name(self, metric_name: str, model_key: Optional[ModelKey] = None):  # noqa: D
+    def get_metric_by_name(self, metric_name: str, model_key: Optional[ModelKey] = None) -> Metric:  # noqa: D
         query = gql(
             """
             query MetricQuery($modelKey: ModelKeyInput, $metricName: String!) {
@@ -919,7 +884,7 @@ class MQLInterface(BaseInterface):  # noqa: D
             error=q["error"] if q["error"] else None,
         )
 
-    def get_queries(self, active_only: bool, limit: Optional[int]) -> Dict[str, Any]:  # type: ignore [misc]
+    def get_queries(self, active_only: bool, limit: Optional[int]) -> List[Query]:
         """Retrieves query status given a query_id"""
         query = gql(
             """
@@ -937,8 +902,10 @@ class MQLInterface(BaseInterface):  # noqa: D
             }
             """
         )
-        # TODO: This should return MQLQueryStatus type
-        return self.execute(query, variable_values={"activeOnly": active_only, "limit": limit})
+        return [
+            Query.from_gql_dict(q)
+            for q in self.execute(query, variable_values={"activeOnly": active_only, "limit": limit})["queries"]
+        ]
 
     def get_logs_by_line(self, query_id: str, from_line: int, max_lines: int = 0) -> Tuple[str, int]:
         """Retrieves logs by log-file line number"""
