@@ -208,7 +208,7 @@ class Metric:
             dimensions=list({d["name"]: Dimension.from_gql_dict(d) for d in _input["dimensionObjects"]}.values()),
         )
 
-    def input_metadata(self, metadata: Dict[str, Any]) -> None:
+    def input_metadata(self, metadata: Dict[str, Any]) -> None:  # type: ignore[misc]
         """Input additional backend metadata."""
         self.description = metadata["description"]
         self.display_name = metadata["displayName"]
@@ -416,7 +416,7 @@ class Dimension:
     cardinality: Optional[int]
 
     @classmethod
-    def from_gql_dict(cls, _input: Dict[str, str]) -> "Dimension":  # noqa: D
+    def from_gql_dict(cls, _input: Dict[str, Any]) -> "Dimension":  # type: ignore[misc] # noqa: D
         return cls(
             name=_input["name"],
             identifier_name=_input["identifierName"],
@@ -426,3 +426,26 @@ class Dimension:
             time_granularity=TimeGranularity(_input["timeGranularity"].lower()) if _input["timeGranularity"] else None,
             cardinality=_input["cardinality"],
         )
+
+
+@dataclass(frozen=True)
+class Query:
+    """Object to represent a Query object."""
+
+    id: int
+    branch: int
+    commit: str
+    metrics: List[str]
+    dimensions: List[str]
+    status: MqlQueryStatus
+
+    @classmethod
+    def from_gql_dict(cls, _input: Dict[str, Any]) -> "Query":  # type: ignore[misc] # noqa: D
+        return cls(
+            id=_input["id"],
+            branch=_input["modelKey"]["branch"],
+            commit=_input["modelKey"]["commit"],
+            metrics=_input["metrics"],
+            dimensions=_input["dimensions"],
+            status=MqlQueryStatus(_input["status"]),
+        )
